@@ -153,12 +153,17 @@ class security_manager {
         }
     }
     
-    public function block_ip($ip_address, $reason = 'Manual block', $failed_attempts = 0, $indefinite = false) {
+    public function block_ip($ip_address, $reason = 'Manual block', $failed_attempts = 0, $indefinite = false, $skip_service_blocks = false) {
         // Don't block whitelisted IPs
         if ($this->is_ip_whitelisted($ip_address)) {
             return false;
         }
         
+        // Check if IP is already blocked in security manager to prevent duplicates
+        if ($this->is_ip_blocked($ip_address)) {
+            return true; // Already blocked, return success
+        }
+        
         // Store in local database
         $unblock_time = $indefinite ? 0 : (time() + $this->block_duration); // 0 means indefinite/manual unblock only
         $stmt = $this->db->prepare('INSERT OR REPLACE INTO blocked_ips (ip_address, block_time, unblock_time, reason, failed_attempts, manual_block) VALUES (:ip, :block_time, :unblock_time, :reason, :attempts, :manual)');
@@ -180,16 +185,18 @@ class security_manager {
             // Continue even if HAProxy blocking fails - local block is still active
         }
         
-        // Also block in SSH/FTP services via log monitor
-        try {
-            require_once('/docker/whp/web/libs/log_monitor_manager.php');
-            $log_monitor = new log_monitor_manager();
-            // Block on both SSH and FTP services
-            $log_monitor->block_service_ip('ssh', $ip_address, $reason, $failed_attempts);
-            $log_monitor->block_service_ip('ftp', $ip_address, $reason, $failed_attempts);
-        } catch (Exception $e) {
-            error_log("Failed to block IP in SSH/FTP services: " . $e->getMessage());
-            // Continue even if service blocking fails
+        // Also block in SSH/FTP services via log monitor (only if not called from service blocks to prevent loops)
+        if (!$skip_service_blocks) {
+            try {
+                require_once('/docker/whp/web/libs/log_monitor_manager.php');
+                $log_monitor = new log_monitor_manager();
+                // Block on both SSH and FTP services
+                $log_monitor->block_service_ip('ssh', $ip_address, $reason, $failed_attempts);
+                $log_monitor->block_service_ip('ftp', $ip_address, $reason, $failed_attempts);
+            } catch (Exception $e) {
+                error_log("Failed to block IP in SSH/FTP services: " . $e->getMessage());
+                // Continue even if service blocking fails
+            }
         }
         
         return true;
