@@ -19,12 +19,56 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
         switch ($_POST['action']) {
             case 'unblock_ip':
                 if (!empty($_POST['ip_address']) && filter_var($_POST['ip_address'], FILTER_VALIDATE_IP)) {
-                    $result = $SecManager->unblock_ip($_POST['ip_address']);
-                    if ($result) {
-                        $message = 'IP address unblocked successfully: ' . htmlspecialchars($_POST['ip_address']);
-                        $message_type = 'success';
+                    $ip_address = $_POST['ip_address'];
+                    $errors = [];
+                    $success_count = 0;
+                    
+                    // Try to unblock from all services and handle errors gracefully
+                    try {
+                        $result1 = $LogMonitor->unblock_ip_from_all_services($ip_address);
+                        if ($result1) {
+                            $success_count++;
+                        }
+                    } catch (Exception $e) {
+                        $errors[] = 'Service unblock: Operation failed';
+                        error_log('Service unblock error for IP ' . $ip_address . ': ' . $e->getMessage());
+                    }
+                    
+                    try {
+                        $result2 = $SecManager->unblock_ip($ip_address);
+                        if ($result2) {
+                            $success_count++;
+                        }
+                    } catch (Exception $e) {
+                        $errors[] = 'Security manager unblock: Operation failed';
+                        error_log('Security manager unblock error for IP ' . $ip_address . ': ' . $e->getMessage());
+                    }
+                    
+                    try {
+                        if (class_exists('haproxy_manager')) {
+                            $HaproxyManager = new haproxy_manager();
+                            $result3 = $HaproxyManager->unblock_ip($ip_address);
+                            if ($result3) {
+                                $success_count++;
+                            }
+                        } else {
+                            $errors[] = 'HAProxy unblock: Service not available';
+                        }
+                    } catch (Exception $e) {
+                        $errors[] = 'HAProxy unblock: Operation failed';
+                        error_log('HAProxy unblock error for IP ' . $ip_address . ': ' . $e->getMessage());
+                    }
+                    
+                    if ($success_count > 0) {
+                        if (empty($errors)) {
+                            $message = 'IP address unblocked successfully from all services: ' . htmlspecialchars($ip_address);
+                            $message_type = 'success';
+                        } else {
+                            $message = 'IP address partially unblocked from ' . $success_count . ' service(s): ' . htmlspecialchars($ip_address) . '. Warnings: ' . implode('; ', $errors);
+                            $message_type = 'warning';
+                        }
                     } else {
-                        $message = 'Error unblocking IP address';
+                        $message = 'Failed to unblock IP address from any service: ' . htmlspecialchars($ip_address) . '. Errors: ' . implode('; ', $errors);
                         $message_type = 'danger';
                     }
                 } else {
@@ -36,7 +80,7 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                 if (!empty($_POST['ip_address']) && filter_var($_POST['ip_address'], FILTER_VALIDATE_IP)) {
                     $reason = !empty($_POST['reason']) ? substr(trim($_POST['reason']), 0, 255) : 'Manual block';
                     $indefinite = isset($_POST['indefinite']) && $_POST['indefinite'] == '1';
-                    $result = $SecManager->block_ip($_POST['ip_address'], $reason, 0, $indefinite);
+                    $result = $SecManager->block_ip($_POST['ip_address'], $reason, 0, $indefinite, false);
                     if ($result) {
                         $block_type = $indefinite ? 'indefinitely' : 'temporarily';
                         $message = 'IP address blocked ' . $block_type . ': ' . htmlspecialchars($_POST['ip_address']);
@@ -119,23 +163,20 @@ if ($_SERVER['REQUEST_METHOD'] === 'POST') {
                 }
                 break;
             case 'unblock_service_ip':
-                if (!empty($_POST['service']) && !empty($_POST['ip_address']) && filter_var($_POST['ip_address'], FILTER_VALIDATE_IP)) {
-                    $allowed_services = ['ssh', 'ftp'];
-                    if (in_array($_POST['service'], $allowed_services)) {
-                        $result = $LogMonitor->unblock_service_ip($_POST['service'], $_POST['ip_address']);
-                        if ($result) {
-                            $message = 'IP address unblocked from ' . strtoupper(htmlspecialchars($_POST['service'])) . ' service: ' . htmlspecialchars($_POST['ip_address']);
-                            $message_type = 'success';
-                        } else {
-                            $message = 'Error unblocking IP address from service';
-                            $message_type = 'danger';
-                        }
+                if (!empty($_POST['ip_address']) && filter_var($_POST['ip_address'], FILTER_VALIDATE_IP)) {
+                    // Unblock from all services and security manager
+                    $result1 = $LogMonitor->unblock_ip_from_all_services($_POST['ip_address']);
+                    $result2 = $SecManager->unblock_ip($_POST['ip_address']);
+                    
+                    if ($result1 || $result2) {
+                        $message = 'IP address unblocked from all services: ' . htmlspecialchars($_POST['ip_address']);
+                        $message_type = 'success';
                     } else {
-                        $message = 'Invalid service specified';
+                        $message = 'Error unblocking IP address - IP may not have been blocked';
                         $message_type = 'danger';
                     }
                 } else {
-                    $message = 'Invalid IP address format or missing service';
+                    $message = 'Invalid IP address format';
                     $message_type = 'danger';
                 }
                 break;
@@ -152,7 +193,7 @@ $recent_logins = $SecManager->get_all_recent_logins(10);
 // Get log monitoring data
 $log_config = $LogMonitor->get_all_config();
 $service_stats = $LogMonitor->get_service_stats();
-$service_blocked_ips = $LogMonitor->get_service_blocked_ips();
+$service_blocked_ips = $LogMonitor->get_unique_blocked_ips();
 
 // Get access statistics
 require_once('/docker/whp/web/libs/permission_manager.php');
@@ -643,25 +684,26 @@ if (!empty($service_blocked_ips)): ?>
                             <tr>
                                 <td>
                                     <?php 
-                                    $service_type = $blocked['service_type'];
+                                    // Show the original service/method that caused the block
+                                    $blocking_service = $blocked['blocking_service'] ?? $blocked['service_type'];
                                     $reason = $blocked['reason'] ?? '';
                                     
-                                    // Determine the actual block source
+                                    // Determine the block source from the reason or blocking service
                                     if (stripos($reason, 'manual') !== false) {
                                         $badge_class = 'warning';
                                         $service_display = 'MANUAL';
-                                    } elseif (stripos($reason, 'whp') !== false) {
+                                    } elseif (stripos($reason, 'whp') !== false || stripos($reason, 'failed login') !== false) {
                                         $badge_class = 'success';
                                         $service_display = 'WHP';
-                                    } elseif ($service_type == 'ssh') {
+                                    } elseif ($blocking_service == 'ssh') {
                                         $badge_class = 'primary';
                                         $service_display = 'SSH';
-                                    } elseif ($service_type == 'ftp') {
+                                    } elseif ($blocking_service == 'ftp') {
                                         $badge_class = 'info';
                                         $service_display = 'FTP';
                                     } else {
                                         $badge_class = 'secondary';
-                                        $service_display = strtoupper($service_type);
+                                        $service_display = strtoupper($blocking_service);
                                     }
                                     ?>
                                     <span class="badge bg-<?php echo $badge_class; ?>"><?php echo $service_display; ?></span>
@@ -707,9 +749,8 @@ if (!empty($service_blocked_ips)): ?>
                                     <form method="POST" action="" style="display:inline;">
                                         <input type="hidden" name="csrf_token" value="<?php echo get_csrf_token(); ?>">
                                         <input type="hidden" name="action" value="unblock_service_ip">
-                                        <input type="hidden" name="service" value="<?php echo htmlspecialchars($blocked['service_type']); ?>">
                                         <input type="hidden" name="ip_address" value="<?php echo htmlspecialchars($blocked['ip_address']); ?>">
-                                        <button type="submit" class="btn btn-warning btn-sm">Unblock</button>
+                                        <button type="submit" class="btn btn-warning btn-sm">Unblock All</button>
                                     </form>
                                 </td>
                             </tr>
